"""
Tests for carta_envoy.launchers
"""
import signal
from pathlib import Path
from unittest.mock import patch

from carta_envoy.launchers import CartaLauncher

test_settings = {
    "timeout": 1,
    "carta_path": "/fake/path/to/nowhere",
    "redis_host": "noplace.nrao.edu",
    "redis_port": "6397",
    "redis_password": "password",
    "reverse_proxy": "black-abyss.nrao.edu",
    "data_location": ".",
    "useCarta": False,
}


launcher = CartaLauncher(settings=test_settings)


class TestCartaLauncher:
    def test_prepare_carta(self):
        with patch("carta_envoy.connect.RedisConnect.prepare_redis") as redis_prep:
            launcher.prepare_for_carta()
            assert redis_prep.call_count == 1

    def test_launch(self):
        with patch("carta_envoy.launchers.CartaLauncher.prepare_for_carta") as prep:
            with patch("carta_envoy.launchers.CartaLauncher.run_carta") as carta:
                launcher.launch()
                assert prep.call_count == 1
                assert carta.call_count == 1

    @patch("subprocess.Popen")
    def test_run_carta(self, mock_subprocess):
        """
        Test that CARTA runs successfully with setup and teardown

        :param caplog: Built-in pytest fixture that allows viewing of logs
        """
        launcher.run_carta(
            path_to_carta="fake_carta_path",
            timeout_minutes=1,
            file_browser_path=Path(),
            front_end_port=6464,
            back_end_port=7777,
            carta_url="carta_url",
        )
        assert mock_subprocess.call_count == 0
